# coding: utf-8

import eu2020.data.colors as colors

app_name = "EU Diktátor 2020"

what_is_your_name = "Jak se jmenuješ? "
what_is_your_gender = "Jakého seš pohlaví? "

cursor = f"[{colors.cursor}]>[/{colors.cursor}] "

proceed = "Pokračovat..."

period = "Období: {} {}"
# budget = "Rozpočet {}: {:,} EUR, rozdíl příjmů a výdajů: {:,} EUR, dluh: {:,} EUR"
membership_satisfaction = "Spokojenost členských států: [{}]{:.2f} %[/{}]"
membership_satisfaction_header = "Spokojenost členských států"
deep_state_satisfaction_header = "Spokojenost deep state"

intro = """
Ahoj {},
gratuluji - právě si se {} šéfem Evropské komise. Tvá síla a možnosti jsou prakticky neomezené.
Vládneš {} členským zemím a tvým úkolem je udržet země co nejdéle v EU.
"""

gender_dict = {
    "stal": {
        "m": "stal",
        "f": "stala",
        "n": "stalo"
    }
}

options = "Možnosti:"
higher_power_event = "Mimořádná událost"
higher_power_events = "Mimořádné události: [{}]{}[/{}]"

budget_income =        "Příjmy:                 "
budget_outcome =       "Výdaje:                 "
budget_balance =       "Bilance:                "
budget_extra_income =  "Mimořádné příjmy:       "
budget_extra_outcome = "Mimořádné výdaje:       "
budget_dept =          "Dluh z minulých období: "
budget_guarantee =     "Poskytnuté garance:     "



# coding: utf-8

ev_deep_state_nez = [
    {
        "party": "NEZ",
        "description": "V Bělorusku proběhly volby ve kterých opět vyhrál prezident Lukašenko. Lidskoprávní organizace "
                       "poukazují na to, že volby byly zmanipulované a požadují odsouzení Běloruska.",
        "options": [
            {
                "key": "p",
                "description": "přijmout deklaraci a odsoudit Bělorusko za zmanipulované volby",
                "delay": -1,
                "flag_set": "belarus_border_conflict",
                "impact": {
                    "satisfaction": {"NEZ": 5},
                }
            },
            {
                "key": "n",
                "description": "nepřijmout deklaraci odsuzující Bělorusko",
                "delay": -1,
                "impact": {
                    "satisfaction": {"NEZ": -10},
                }
            },
        ]
    },
    {
        "party": "NEZ",
        "description": "Běloruský prezident Lukašenko v rámci odvetné hybridní války začal posílat Afghánské "
                       "a Irácké uprchlíky přes hranici s Polskem a Litvou. Obě země následně začaly své hranice "
                       "s Běloruskem opevňovat a stavět proti-imigrační plot. Neziskové lidskoprávní organizace "
                       "požadují okamžité odstranění plotu a volný průchod pro uprchlíky.",
        "flag": "belarus_border_conflict",
        "options": [
            {
                "key": "o",
                "description": "přikázat Polsku a Litvě odstranění plotu",
                "delay": -1,
                "impact": {
                    "satisfaction": {"PL": -5, "LT": -5, "NEZ": 3},
                }
            },
            {
                "key": "s",
                "description": "schválit ochranu vnějších hranic s Běloruskem",
                "delay": -1,
                "impact": {
                    "satisfaction": {"PL": 3, "LT": 3, "NEZ": -5},
                }
            },
            {
                "key": "n",
                "description": "nerozhodnout teď",
                "delay": 2,
                "impact": {
                }
            },
        ]
    },
]



# coding: utf-8

ev_member_country_cz = [
    {
        "party": "CZ",
        "description": "České opoziční strany požadují deklaraci proti střetu zájmů českého premiéra.",
        "options": [
            {
                "key": "p",
                "description": "přijmout deklaraci",
                "delay": -1,
                "impact": {
                    "satisfaction": {"CZ": -3, "HU": -3, "PL": -3, "SK": -1},
                }
            },
            {
                "key": "o",
                "description": "odmítnout deklaraci",
                "delay": -1,
                "impact": {
                    "satisfaction": {"CZ": 1, "HU": 1, "PL": 1, "SK": 1},
                }
            },
            {
                "key": "n",
                "description": "nerozhodnout teď",
                "delay": 2,
                "impact": {
                }
            },
        ]
    },
    {
        "party": "CZ",
        "description": "České tajné služby přinesly informaci, že za výbuchy muničních skladů ve Vrběticích stojí "
                       "ruští agenti. Česká vláda žádá společnou reakci na úrovni EU.",
        "options": [
            {
                "key": "d",
                "description": "přijmout deklaraci a odsoudit Rusko za operace na území svrchovaného státu",
                "delay": -1,
                "flag_set": "vrbetice",
                "impact": {
                    "satisfaction": {"CZ": 5, "RU": -5},
                }
            },
            {
                "key": "s",
                "description": "odsoudit Rusko a přijmou sankce",
                "delay": -1,
                "flag_set": "vrbetice",
                "impact": {
                    "satisfaction": {"CZ": 5, "RU": -10},
                }
            },
            {
                "key": "o",
                "description": "odmítnout společnou reakci na úrovni EU",
                "delay": -1,
                "impact": {
                    "satisfaction": {"CZ": -5, "RU": 5},
                }
            },
            {
                "key": "n",
                "description": "nerozhodnout teď",
                "delay": 2,
                "impact": {
                }
            },
        ]
    },
]



import eu2020.data.data as data


class Period:

    def __init__(self, year: int, month: int):
        self.year = year
        self.month = month

    def next(self) -> None:
        self.month += 1
        if self.month == len(data.months):
            self.month = 0
            self.year += 1

    def get_year(self) -> int:
        return self.year

    def get_month(self) -> str:
        return data.months[self.month]



# coding: utf-8

ev_member_country_de = [
    {
        "party": "DE",
        "description": "Němečtí Zelení chtějí prosadit uzavření všech fosilních elektráren v EU.",
        "options": [
            {
                "key": "p",
                "description": "přijmout rozhodnutí o uzavření fosilních elektráren",
                "delay": -1,
                "impact": {
                    "satisfaction": {
                        "BE": -1, "BG": -1, "CZ": -3, "DK": -1, "EE": -2, "FI": -2, "FR": -2, "HR": -1, "IE": -1, "IT": -2,
                        "CY": -1, "LT": -2, "ES": -2, "SE": -2, "HU": -3, "MT": -1, "DE": +2, "NL": -2, "PL": -3, "PT": -1,
                        "AT": -2, "RO": -3, "GR": -1, "SK": -3, "SI": -2, "LV": -2, "LU": -2,
                    },
                }
            },
            {
                "key": "o",
                "description": "odmítnou rozhodnutí o uzavření fosilních elektráren",
                "delay": 12,
                "impact": {
                    "satisfaction": {"DE": -5, },
                }
            },
            {
                "key": "n",
                "description": "nerozhodnout teď",
                "delay": 2,
                "impact": {
                }
            },
        ]
    },
]



# coding: utf-8

from eu2020.data.ev_others_ru import ev_others_ru

ev_others = []
ev_others += ev_others_ru

deep_others = {
    "RU": {
        "name": "Rusko",
        "satisfaction_pct": 50,
        "budget_contribution": 0,
        "budget_consumption": 0,
    },
    "CN": {
        "name": "Čína",
        "satisfaction_pct": 50,
        "budget_contribution": 0,
        "budget_consumption": 0,
    },
    "US": {
        "name": "USA",
        "satisfaction_pct": 50,
        "budget_contribution": 0,
        "budget_consumption": 0,
    },
}



# coding: utf-8

ev_member_country_pl = [
    {
        "party": "PL",
        "description": "Polsko zavádí zóny bez LGBT. Aktivisté požadují přísné potrestání Polska.",
        "options": [
            {
                "key": "p",
                "description": "přijmout deklaraci a odsoudit Polsko",
                "delay": -1,
                "impact": {
                    "satisfaction": {"CZ": -3, "HU": -3, "PL": -10, "SK": -1},
                }
            },
            {
                "key": "k",
                "description": "udělit pokutu 200 000 000 EUR",
                "delay": -1,
                "impact": {
                    "satisfaction": {"CZ": -3, "HU": -3, "PL": -10, "SK": -1},
                    "budget": 200_000_000,
                }
            },
            {
                "key": "n",
                "description": "nerozhodnout teď",
                "delay": 2,
                "impact": {
                }
            },
        ]
    },
    {
        "party": "PL",
        "description": "Polsko udělalo krok k odchodu z Evropské unie. Ústavní soud rozhodl, že polské právo "
                       "je nadřazené unijnímu. Postavení ústav a jejich ustanoveních jsou předmětem vášnivé debaty "
                       "v právnické komunitě v celé Evropské unii.",
        "options": [
            {
                "key": "k",
                "description": "udělit pokutu 200 000 000 EUR a zahájit kroky k vyloučení Polska z EU",
                "delay": -1,
                "impact": {
                    "satisfaction": {"PL": -5},
                    "budget": 200_000_000,
                }
            },
            {
                "key": "p",
                "description": "přijmout deklaraci proti Polsku a udělit pokutu  200 000 000 EUR",
                "delay": -1,
                "impact": {
                    "satisfaction": {"PL": -5},
                    "budget": 200_000_000,
                }
            },
            {
                "key": "n",
                "description": "nerozhodnout teď",
                "delay": 2,
                "impact": {
                }
            },
        ]
    },
]



# coding: utf-8

ev_member_country_hu = [
    {
        "party": "HU",
        "description": "Maďarsko zakázalo propagaci LGBT ve školách. LGBT aktivisté požadují odsoudit Maďarsko za porušování."
                       " práv menšin",
        "options": [
            {
                "key": "p",
                "description": "přijmout deklaraci a odsoudit Maďarsko za porušování práv menšin LGBT",
                "delay": -1,
                "impact": {
                    "satisfaction": {"CZ": -3, "HU": -8, "PL": -3, "SK": -1},
                }
            },
            {
                "key": "k",
                "description": "udělit pokutu 200 000 000 EUR",
                "delay": -1,
                "impact": {
                    "satisfaction": {"CZ": -3, "HU": -8, "PL": -3, "SK": -1},
                    "budget": 200_000_000,
                }
            },
            {
                "key": "o",
                "description": "odmítnout deklaraci",
                "delay": -1,
                "impact": {
                    "satisfaction": {"CZ": 3, "HU": 8, "PL": 3, "SK": 1},
                }
            },
            {
                "key": "n",
                "description": "nerozhodnout teď",
                "delay": 2,
                "impact": {
                }
            },
        ]
    },
    {
        "party": "HU",
        "description": "Maďarsko postavilo plot proti uprchlíkům přicházejícím ze Srbska a Chorvatska. "
                       "Lidskoprávní organizace požadují okamžité odstranění plotu.",
        "flag": "turkey_refugee_agreement",
        "options": [
            {
                "key": "o",
                "description": "nařídit Maďarsku odstranění plotu",
                "delay": -1,
                "flag_set": "fence_hu",
                "impact": {
                    "satisfaction": {"CZ": -3, "HU": -8, "PL": -3, "SK": -1, "NEZ": 3, "SOR": 3},
                }
            },
            {
                "key": "s",
                "description": "odsouhlasit plot jako zlepšení ochrany vnějších hranic EU",
                "delay": -1,
                "flag_set": "fence_hu",
                "impact": {
                    "satisfaction": {"CZ": 3, "HU": 8, "PL": 3, "SK": 1, "NEZ": -5, "SOR": -5},
                    "budget": 200_000_000,
                }
            },
            {
                "key": "n",
                "description": "nerozhodnout teď",
                "delay": 2,
                "impact": {
                }
            },
        ]
    },
]



# coding: utf-8

ev_deep_state_who = [
    {
        "party": "WHO",
        "description": "V souvislosti s probíhající pandemií WHO založila nadační fond COVAX, který má financovat nákup"
                       " a distiribuci vakcín po celém světe. WHO žádá Evropskou unii o příspěvek 10 000 000 000 EUR",
        "flag": "pandemic",
        "options": [
            {
                "key": "p",
                "description": "přijmout",
                "delay": -1,
                "impact": {
                    "satisfaction": {"WHO": 20, "NEZ": 10, "NBM": 10, "SOR": 5, "GDA": 5, "BIP": 10},
                    "budget": -10_000_000_000,
                }
            },
            {
                "key": "o",
                "description": "odmítnout",
                "delay": 6,
                "impact": {
                    "satisfaction": {"WHO": -10, "NEZ": -5, "NBM": -5, "SOR": -5, "GDA": -5, "BIP": -5},
                }
            },
            {
                "key": "n",
                "description": "nerozhodnout teď",
                "delay": 2,
                "impact": {
                    "satisfaction": {"WHO": -2},
                }
            },
        ]
    },
]



# coding: utf-8

ev_admin_es = [
    {
        "party": "ES",
        "description": "Lichtenštejnsko se obrátito na Evropský soud pro lidská práva ve věci "
                       "navrácení zabaveného majetku. Po válce byly totiž na majetek Lichtenštejnů "
                       "uplatněny dekrety prezidenta Beneše. Knížecí rodina tvrdí, že jí český stát "
                       "zabavil majetek nezákonně, protože vládnoucí kníže se za Němce neprohlásil "
                       "a byl hlavou suverénního státu, který za války zachovával neutralitu.",
        "options": [
            {
                "key": "p",
                "description": "podpořit Lichtenštejnsko u Evropského soudu",
                "delay": -1,
                "impact": {
                    "satisfaction": {
                        "CZ": -5
                    },
                }
            },
            {
                "key": "e",
                "description": "nepodpořit Lichtenštejnsko u Evropského soudu",
                "delay": -1,
                "impact": {
                    "satisfaction": {
                        "CZ": 2
                    },
                }
            },
            {
                "key": "n",
                "description": "nerozhodnout teď",
                "delay": 2,
                "impact": {
                    "satisfaction": {},
                }
            },
        ]
    },
    {
        "party": "ES",
        "description": "V Polsku začala platit sporná novela o trestání soudců (takzvaný náhubkový zákon). "
                       "Polská opozice a další kritici novinek varují, že upravené předpisy umožní trestat a "
                       "odvolat z funkce neposlušné soudce, kteří se staví proti změnám v justici prosazovaným "
                       "současnou národně-konzervativní vládou. Evropský soud navrhuje pro Polsko pokutu "
                       "1 000 000 EUR za každý den platnosti sporného zákona. Nicméně existuje riziko "
                       "že Polsko bude následně vetovat Unijní rozpočet.",
        "options": [
            {
                "key": "p",
                "description": "podpořit pokutu 1 000 000 EUR za každý den platnosti sporného zákona",
                "delay": -1,
                "impact": {
                    "satisfaction": {"PL": -10},
                    "budget": 365_000_000,
                }
            },
            {
                "key": "o",
                "description": "nepodpořit pokutu",
                "delay": -1,
                "impact": {
                    "satisfaction": {"PL": 2},
                }
            },
            {
                "key": "n",
                "description": "nerozhodnout teď",
                "delay": 2,
                "impact": {
                }
            },
        ]
    },
]



import os
import eu2020.data.texts as texts
import eu2020.data.colors as colors
from eu2020 import console


def print_text_in_box(text: str, ch="*") -> None:
    boxw = len(text) + 4
    for _ in range(boxw):
        console.print(ch, end="", style=colors.header_style)
    console.print(f"\n{ch} [{colors.header_1}]{text}[/{colors.header_1}] [{colors.header_style}]{ch}[/{colors.header_style}]")
    for _ in range(boxw):
        console.print(ch, end="")
    print("\n")


def input_with_options(question: str, options: dict) -> str:
    a = None
    while a not in options:
        console.print(f"[{colors.header_2}]{question}[/{colors.header_2}]")
        for o in options:
            console.print(f"[{colors.option}]{o}[/{colors.option}] - {options[o]}")
        a = console.input(texts.cursor)
    clear()
    return a


def proceed() -> None:
    console.input(f"[{colors.proceed}]{texts.proceed}[/{colors.proceed}]")
    clear()


def clear() -> None:
    os.system('cls' if os.name == 'nt' else 'clear')



# coding: utf-8

import re
import eu2020.data.texts as texts

ch5p = [
    (r"(.*)a$", "o"),
    (r"(.*)el$", "le"),
    (r"(.*)l$", "le"),
    (r"(.*)m$", "me"),
    (r"(.*)n$", "ne"),
    (r"(.*)or$", "ore"),
    (r"(.*)r$", "ře"),
    (r"(.*)š$", "ši"),
    (r"(.*)v$", "ve"),
]


class Name:

    def __init__(self, name: str, gender: str):
        self.name = name
        self.gender = gender

    def get_name1p(self) -> str:
        return self.name

    def get_name5p(self) -> str:
        if self.gender != "n":
            for regex, suffix in ch5p:
                pattern = re.compile(regex)
                if pattern.match(self.name) is not None:
                    return pattern.sub(r"\1" + suffix, self.name)
        return self.name

    def translate(self, word: str) -> str:
        t = texts.gender_dict.get(word)
        if t is not None:
            return t[self.gender]
        return word



# coding: utf-8

from eu2020.data.ev_deep_state_nbm import ev_deep_state_nbm
from eu2020.data.ev_deep_state_nez import ev_deep_state_nez
from eu2020.data.ev_deep_state_sor import ev_deep_state_sor
from eu2020.data.ev_deep_state_who import ev_deep_state_who

ev_deep_state = []
ev_deep_state += ev_deep_state_nbm
ev_deep_state += ev_deep_state_nez
ev_deep_state += ev_deep_state_sor
ev_deep_state += ev_deep_state_who

deep_state = {
    "GDA": {
        "name": "Globalisti z Davosu",
        "satisfaction_pct": 50,
        "budget_contribution": 0,
        "budget_consumption": 0,
    },
    "SOR": {
        "name": "George Soros",
        "satisfaction_pct": 50,
        "budget_contribution": 0,
        "budget_consumption": 0,
    },
    "NBM": {
        "name": "Nadace Billa a Melindy Gatesových",
        "satisfaction_pct": 50,
        "budget_contribution": 0,
        "budget_consumption": 0,
    },
    "NEZ": {
        "name": "Neziskové organizace",
        "satisfaction_pct": 50,
        "budget_contribution": 0,
        "budget_consumption": 4_816_000_000,
    },
    "WHO": {
        "name": "Světová Zdravotnická Organizace",
        "satisfaction_pct": 50,
        "budget_contribution": 0,
        "budget_consumption": 2_000_000_000,
    },
    "BIT": {
        "name": "Big Tech Korporace",
        "satisfaction_pct": 50,
        "budget_contribution": 0,
        "budget_consumption": 0,
    },
    "BIP": {
        "name": "Big Pharma Korporace",
        "satisfaction_pct": 50,
        "budget_contribution": 0,
        "budget_consumption": 0,
    },
}



# coding: utf-8

ev_member_country_it = [
    {
        "party": "IT",
        "description": "Itálie požaduje záruku za vydané státní dluhopisy ve výši 10 000 000 000 EUR.",
        "options": [
            {
                "key": "p",
                "description": "přijmout záruku",
                "delay": 12,
                "impact": {
                    "satisfaction": {"IT": 5},
                    "guarantee": 10_000_000_000
                }
            },
            {
                "key": "n",
                "description": "nepřijmout záruku",
                "delay": 3,
                "impact": {
                    "satisfaction": {"IT": -5},
                }
            },
        ]
    },
    {
        "party": "IT",
        "description": "V Itálii hrozí bankrot některých významných bank. Pokud by se tak stalo, znamenalo by to "
                       "nebezpečnou destabilizaci, která by mohla vyústit v odchod zěmě z EU. Itálie proto požaduje "
                       "mimořádnou dotaci na sanaci bank ve výši 12 000 000 000 EUR.",
        "options": [
            {
                "key": "p",
                "description": "poskytnout mimořádnou dotaci ve výši 12 000 000 000 EUR",
                "delay": 24,
                "impact": {
                    "satisfaction": {"IT": 5},
                    "budget": -12_000_000_000
                }
            },
            {
                "key": "o",
                "description": "odmítnout poskytnutí dotace na sanaci italských bank",
                "delay": 3,
                "impact": {
                    "satisfaction": {"IT": -5},
                }
            },
            {
                "key": "n",
                "description": "nerozhodnout teď",
                "delay": 2,
                "impact": {
                    "satisfaction": {"IT": -1},
                }
            },
        ]
    },
]



import random


class HigherPowerEvents:

    events = []
    flags = set()

    def __init__(self, events: list, flags: set):
        self.events = events
        self.flags = flags

    def get_event(self) -> str:
        result = None
        i = random.randint(0, 2)
        if i == 0:
            ev = random.choice(self.events)
            if ev["key"] in self.flags:
                self.flags.remove(ev["key"])
                result = ev["end"]
            else:
                self.flags.add(ev["key"])
                result = ev["start"]
        return result

    def get_current_events(self) -> str:
        return ", ".join(ev["name"] for ev in self.events if ev["key"] in self.flags)



# coding: utf-8

ev_admin_ek = [
    {
        "party": "EK",
        "description": "Evropská komise připravila Zelenou Dohodu (Green Deal), která představuje soubor "
                       "politických iniciativ, jejichž hlavním cílem je dosáhnout toho, aby Evropa byla v "
                       "roce 2050 klimaticky neutrální. Obsahuje plán s vyhodnocenými dopady, jejíž cílem "
                       "je snížit emise skleníkových plynů EU do roku 2030 o 55 % ve srovnání s rokem 1990.",
        "options": [
            {
                "key": "p",
                "description": "přijmout Green Deal",
                "delay": -1,
                "flag_set": "green_deal",
                "impact": {
                    "satisfaction": {
                        "NBM": 2, "WHO": 2, "GDA": 2, "SOR": 2, "BIT": 2, "BE": -2, "BG": -2, "CZ": -2, "DK": -2,
                        "EE": -2, "FI": -1, "FR": -2, "HR": -1, "IE": -1, "IT": -1, "CY": -2, "LT": -2, "ES": -2, "SE": -1,
                        "HU": -2, "MT": -1, "DE": -1, "NL": -1, "PL": -2, "PT": -1, "AT": -1, "RO": -2, "GR": -1, "SK": -2,
                        "SI": -1, "LV": -1, "LU": -1,
                    },
                }
            },
            {
                "key": "o",
                "description": "odmítnout Green Deal",
                "delay": 12,
                "impact": {
                    "satisfaction": {
                        "NBM": -1, "WHO": -1, "GDA": -1, "SOR": -1, "BIT": -1, "BE": 1, "BG": 1, "CZ": 1, "DK": 1,
                        "EE": 1, "FI": 1, "FR": 1, "HR": 1, "IE": 1, "IT": 1, "CY": 1, "LT": 1, "ES": 1, "SE": 1, "HU": 1,
                        "MT": 1, "DE": 1, "NL": 1, "PL": 1, "PT": 1, "AT": 1, "RO": 1, "GR": 1, "SK": 1, "SI": 1, "LV": 1,
                        "LU": 1,
                    },
                }
            },
            {
                "key": "n",
                "description": "nerozhodnout teď",
                "delay": 2,
                "impact": {
                    "satisfaction": {"GDA": -1, "SOR": -1},
                }
            },
        ]
    },
    {
        "party": "EK",
        "description": "EK navrhuje v rámci Green Deal zavedení klimatické daně pro všechny majitele domů a aut.",
        "flag": "green_deal",
        "options": [
            {
                "key": "p",
                "description": "přijmout zavedení klimatické daně pro domácnosti",
                "delay": -1,
                "impact": {
                    "satisfaction": {
                        "WHO": 2, "GDA": 2, "SOR": 2, "BE": -2, "BG": -2, "CZ": -2, "DK": -2,
                        "EE": -2, "FI": -1, "FR": -2, "HR": -1, "IE": -1, "IT": -1, "CY": -2, "LT": -2, "ES": -2, "SE": -1,
                        "HU": -2, "MT": -1, "DE": -1, "NL": -1, "PL": -2, "PT": -1, "AT": -1, "RO": -2, "GR": -1, "SK": -2,
                        "SI": -1, "LV": -1, "LU": -1,
                    },
                }
            },
            {
                "key": "o",
                "description": "odmítnout zavedení klimatické daně pro domácnosti",
                "delay": 6,
                "impact": {
                    "satisfaction": {"WHO": -1, "GDA": -1, "SOR": -1},
                }
            },
            {
                "key": "n",
                "description": "nerozhodnout teď",
                "delay": 2,
                "impact": {
                    "satisfaction": {},
                }
            },
        ]
    },
    {
        "party": "EK",
        "description": "Polsko, Česko, Slovensko a Maďarsko odmítly plán na přerozdělování uprchlíků. "
                       "EK proto navrhuje podání žaloby na tyto země k Evropskému soudu.",
        "flag": "refugee_distribution",
        "options": [
            {
                "key": "s",
                "description": "odsouhlasit podání žaloby na Polsko, Česko, Slovensko a Maďarsko",
                "delay": -1,
                "impact": {
                    "satisfaction": {"CZ": -3, "HU": -3, "PL": -3, "SK": -3, "FR": 1, "IT": 1, "GR": 1, "ES": 1},
                }
            },
            {
                "key": "o",
                "description": "odmítnout podání žaloby na Polsko, Česko, Slovensko a Maďarsko",
                "delay": -1,
                "impact": {
                    "satisfaction": {"CZ": 1, "HU": 1, "PL": 1, "SK": 1, "FR": -3, "IT": -3, "GR": -3, "ES": -3},
                }
            },
            {
                "key": "n",
                "description": "nerozhodnout teď",
                "delay": 2,
                "impact": {
                    "satisfaction": {"FR": -1, "IT": -1, "GR": -1, "ES": -1},
                }
            },
        ]
    },
]



# coding: utf-8

ev_admin_eb = [
    {
        "party": "EB",
        "description": "Evropská centrální banka navrhuje řešit vysokou míru inflace zvednutím úrkokových "
                       "sazeb (tj. zdražením úvěrů). Toto opatření ale může vážně ohrozit státy s vysokým "
                       "zadlužením jako je Itálie, Francie a Španělsko a plánované opatření by je mohlo dovést "
                       "k bankrotu.",
        "flag": "inflation",
        "options": [
            {
                "key": "p",
                "description": "podpořit opatření proti inflaci zvednutím úrokových sazeb",
                "delay": 12,
                "impact": {
                    "satisfaction": {"FR": -3, "IT": -5, "ES": -3, "GR": -2},
                }
            },
            {
                "key": "o",
                "description": "odmítnout opatření proti inflaci zvednutím úrokových sazeb",
                "delay": 12,
                "impact": {
                    "satisfaction": {"FR": 1, "IT": 1, "ES": 1, "GR": 1},
                }
            },
            {
                "key": "n",
                "description": "nerozhodnout teď",
                "delay": 2,
                "impact": {
                    "satisfaction": {},
                }
            },
        ]
    },
    {
        "party": "EB",
        "description": "Evropská centrální banka navrhuje řešit probíhající hospodářskou recesi takzvaným "
                       "kvantitativním uvolňováním (pumpováním peněz do ekonomiky). Důsledkem tohoto opatření "
                       "je ale růst inflace.",
        "flag": "economic_recession",
        "options": [
            {
                "key": "t",
                "description": "podpořit kvatntitativní uvolňování tiskem nových peněz",
                "delay": 12,
                "impact": {
                    "satisfaction": {"FR": 2, "IT": 2, "ES": 2, "GR": 2},
                }
            },
            {
                "key": "s",
                "description": "podpořit kvatntitativní uvolňování zavedením záporných úrokových sazeb",
                "delay": 12,
                "impact": {
                    "satisfaction": {"FR": 2, "IT": 2, "ES": 2, "GR": 2},
                }
            },
            {
                "key": "o",
                "description": "odmítnout zavedení kvantitativního uvolňování",
                "delay": 12,
                "impact": {
                    "satisfaction": {},
                }
            },
            {
                "key": "n",
                "description": "nerozhodnout teď",
                "delay": 2,
                "impact": {
                    "satisfaction": {},
                }
            },
        ]
    },
]



# coding: utf-8

ev_higher_power = [
    {
        "key": "pandemic",
        "name": "Pandemie",
        "start": "Propukla pandemie nové neznámé choroby.",
        "end": "Pandemie ustoupila.",
    },
    {
        "key": "floods_de",
        "name": "Povodně v Německu",
        "start": "V Německu propukly povodně.",
        "end": "Povodně v Německu se podařilo zvládnout.",
    },
    {
        "key": "inflation",
        "name": "Inflace",
        "start": "Evropa se potýká s vysokou mírou inflace. Lidé se bojí o své úspory.",
        "end": "Inflaci se podařilo zvládnout.",
    },
    {
        "key": "economic_recession",
        "name": "Hospodářská recese",
        "start": "Evropou zmítá hospodářská recese, podniky propouštějí.",
        "end": "Hospodářskou recesi se podařilo zvládnout.",
    },
    {
        "key": "fires_gr",
        "name": "Požáry v Řecku",
        "start": "V Řecku propukly lesní požáry.",
        "end": "Lesní požáry v Řecku se podařilo zvládnout.",
    },
]



# coding: utf-8

ev_member_country_gr = [
    {
        "party": "GR",
        "description": "Řecko se potýká s náporem uprchlíků přicházejících z Turecka a požaduje příjmutí urychleného plánu"
                       " na přerozdělování uprchlíků v Evropě.",
        "options": [
            {
                "key": "p",
                "description": "přijmout urychleně plán pro spravedlivé přerozdělování uprchlíků",
                "delay": -1,
                "flag_set": "refugee_distribution",
                "impact": {
                    "satisfaction": {"CZ": -3, "HU": -3, "PL": -3, "SK": -1, "AT": -3, "GR": 5, "IT": 4, "ES": 4},
                }
            },
            {
                "key": "n",
                "description": "nerozhodnout teď",
                "delay": 2,
                "impact": {
                    "satisfaction": {"GR": -5},
                }
            },
        ]
    },
    {
        "party": "GR",
        "description": "Řecko požaduje záruku za vydané státní dluhopisy ve výši 5 000 000 000 EUR.",
        "options": [
            {
                "key": "p",
                "description": "přijmout záruku",
                "delay": 12,
                "impact": {
                    "satisfaction": {"GR": 5},
                    "guarantee": 5_000_000_000
                }
            },
            {
                "key": "n",
                "description": "nepřijmout záruku",
                "delay": 2,
                "impact": {
                    "satisfaction": {"GR": -5},
                }
            },
        ]
    },
    {
        "party": "GR",
        "description": "Řecko požaduje mimořádnou dotaci ve výši 500 000 000 EUR na zvládnutí lesních požárů.",
        "flag": "fires_gr",
        "options": [
            {
                "key": "p",
                "description": "poskytnout dotaci",
                "delay": 12,
                "impact": {
                    "satisfaction": {"GR": 2},
                    "budget": -500_000_000,
                }
            },
            {
                "key": "n",
                "description": "neposkytnout dotaci",
                "delay": 3,
                "impact": {
                    "satisfaction": {"GR": -5},
                }
            },
        ]
    },
    {
        "party": "GR",
        "description": "Řecko zaznamenává masivní vlny přílivu uprchlíků přes Středozemní moře. Požaduje uzavření dohody"
                       " s Tureckem a zaplacení 6 mld EUR aby zadržovalo uprchlíky.",
        "options": [
            {
                "key": "u",
                "description": "uzavřít dohodu a zaplatit Turecku 6 mld EUR aby zadržovlo uprchlíky",
                "delay": -1,
                "flag_set": "turkey_refugee_agreement",
                "impact": {
                    "satisfaction": {
                        "BE": -1, "BG": -1, "CZ": -2, "DK": -1, "EE": -2, "FI": -2, "FR": 2, "HR": 1, "IT": 2, "CY": -10,
                        "LT": -2, "ES": -2, "SE": -2, "HU": -2, "MT": 1, "DE": -1, "NL": -2, "PL": -2, "PT": -1, "AT": -2,
                        "RO": -3, "GR": 5, "SK": 1, "LV": -2, "LU": -2,
                    },
                    "budget": -6_000_000_000,
                }
            },
            {
                "key": "o",
                "description": "odmítnout uzavření dohody s Tureckem",
                "delay": 12,
                "impact": {
                    "satisfaction": {"GR": -5, "CY": 3},
                }
            },
            {
                "key": "n",
                "description": "nerozhodnout teď",
                "delay": 2,
                "impact": {
                }
            },
        ]
    },
]



import copy
import statistics

import eu2020.data.colors as colors


class Parties:

    parties = {}
    parties_prev = {}

    def __init__(self, parties: dict):
        self.parties = parties
        self.parties_prev = copy.deepcopy(self.parties)

    def get_satisfaction_pct(self) -> float:
        return statistics.mean(
            party["satisfaction_pct"] for party in self.parties.values()
        )

    def get_detailed_satisfaction_report(self) -> str:
        result = ""
        w = 0
        for c in self.parties:
            t = len(self.parties[c]["name"])
            if w < t:
                w = t
        w += 3
        for c in self.parties:
            result += self.parties[c]["name"]
            for _ in range(w - len(self.parties[c]["name"])):
                result += " "
            result += "[{}]{:.2f} %[/{}]".format(colors.numbers, self.parties[c]["satisfaction_pct"], colors.numbers)
            diff = self.parties[c]["satisfaction_pct"] - self.parties_prev[c]["satisfaction_pct"]
            if diff > 0:
                result += "  ([{}]{:+.2f} %[/{}])".format(colors.positive_progress, diff, colors.positive_progress)
            if diff < 0:
                result += "  ([{}]{:+.2f} %[/{}])".format(colors.negative_progress, diff, colors.negative_progress)
            result += "\n"
        return result

    def update_satisfaction(self, satisfaction: dict) -> None:
        for c in satisfaction:
            self.parties[c]["satisfaction_pct"] += satisfaction[c]
            if self.parties[c]["satisfaction_pct"] < 0:
                self.parties[c]["satisfaction_pct"] = 0

    def get_budget_contribution(self) -> int:
        result = 0
        for c in self.parties:
            result += self.parties[c]["budget_contribution"]
        return result

    def get_budget_consumption(self) -> int:
        result = 0
        for c in self.parties:
            result += self.parties[c]["budget_consumption"]
        return result

    def next_period(self) -> None:
        self.parties_prev = copy.deepcopy(self.parties)



# coding: utf-8

ev_others_ru = [
    {
        "party": "RU",
        "description": "Ruský prezident Vladimir Putin ostře pokáral transgender ideologii "
                       "a označil ji za 'zločin proti lidskosti', když tvrdí, že děti mohou změnit pohlaví.",
        "options": [
            {
                "key": "p",
                "description": "přijmout deklaraci a ostře odsoudit Rusko za porušování práv menšin LGBT",
                "delay": -1,
                "impact": {
                    "satisfaction": {"NEZ": 10, "HU": -1, "PL": -1},
                }
            },
            {
                "key": "i",
                "description": "ignorovat",
                "delay": -1,
                "impact": {
                    "satisfaction": {"NEZ": -8},
                }
            },
            {
                "key": "n",
                "description": "nerozhodnout teď",
                "delay": 2,
                "impact": {
                    "satisfaction": {"NEZ": -1},
                }
            },
        ]
    },
    {
        "party": "RU",
        "description": "Rusko prohlásilo obvinění týkající se výbuchu skladů ve Vrběticích za "
                       "vykonstruované a pohrozilo odvetnými kroky.",
        "flag": "vrbetice",
        "options": [
            {
                "key": "p",
                "description": "podniknout diplomatické kroky ke zmírnění napětí",
                "delay": -1,
                "impact": {
                    "satisfaction": {"RU": 3},
                }
            },
            {
                "key": "i",
                "description": "ignorovat",
                "delay": -1,
                "impact": {
                }
            },
        ]
    },
]



import eu2020.data.colors as colors
import eu2020.data.texts as texts
from eu2020.common.parties import Parties


class Budget:

    parties = []
    budget = {
        "extra_income": 0,
        "extra_outcome": 0,
        "dept": 0,
        "guarantee": 0
    }

    def add_parties(self, parties: Parties) -> None:
        self.parties.append(parties)

    def get_balance(self) -> int:
        return self.get_income() + self.get_extra_income() \
            - self.get_outcome() - self.get_extra_outcome() - self.get_dept()

    def get_dept(self) -> int:
        return self.budget["dept"]

    def get_income(self) -> int:
        result = 0
        for p in self.parties:
            result += p.get_budget_contribution()
        return result

    def get_outcome(self) -> int:
        result = 0
        for p in self.parties:
            result += p.get_budget_consumption()
        return result

    def get_extra_income(self):
        return self.budget["extra_income"]

    def get_extra_outcome(self):
        return self.budget["extra_outcome"]

    def get_guarantee(self):
        return self.budget["guarantee"]

    def add_extra_income(self, amt: int) -> None:
        self.budget["extra_income"] += amt

    def add_extra_outcome(self, amt: int) -> None:
        self.budget["extra_outcome"] += amt

    def add_guarantee(self, amt: int) -> None:
        self.budget["guarantee"] += amt

    def update_balance(self) -> None:
        self.budget["dept"] -= self.get_income() + self.budget["extra_income"] \
            - self.get_outcome() - self.budget["extra_outcome"] \
            - int(self.get_guarantee() * 0.25)
        self.budget["extra_income"] = 0
        self.budget["extra_outcome"] = 0
        self.budget["guarantee"] = int(self.get_guarantee() * 0.5)

    def get_budget_report(self):
        result = ""

        result += "{} [{}]{:20,} EUR[/{}]\n" \
            .format(texts.budget_income, colors.numbers, self.get_income(), colors.numbers)
        result += "{} [{}]{:20,} EUR[/{}]\n" \
            .format(texts.budget_outcome, colors.numbers, self.get_outcome(), colors.numbers)
        result += "{} [{}]{:20,} EUR[/{}]\n" \
            .format(texts.budget_extra_income, colors.numbers, self.get_extra_income(), colors.numbers)
        result += "{} [{}]{:20,} EUR[/{}]\n" \
            .format(texts.budget_extra_outcome, colors.numbers, self.get_extra_outcome(), colors.numbers)
        result += "{} [{}]{:20,} EUR[/{}]\n" \
            .format(texts.budget_dept, colors.numbers, self.get_dept(), colors.numbers)

        diff = self.get_balance()
        color = colors.numbers
        if diff > 0:
            color = colors.positive_progress
        if diff < 0:
            color = colors.negative_progress
        result += "{} [{}]{:{}20,} EUR[/{}]\n".format(texts.budget_balance, color, diff, '+' if diff else '', color)

        result += "{} [{}]{:20,} EUR[/{}]\n" \
            .format(texts.budget_guarantee, colors.numbers, self.get_guarantee(), colors.numbers)

        return result



# coding: utf-8

ev_member_country_lu = [
    {
        "party": "LU",
        "description": "Lucemburský šéf diplomacie požaduje vyloučení Maďarska z EU kvůli přístupu k uprchlíkům.",
        "flag": "fence_hu",
        "options": [
            {
                "key": "z",
                "description": "zahájit kroky k vyloučení Maďarska z EU",
                "delay": -1,
                "impact": {
                    "satisfaction": {"CZ": -3, "HU": -10, "PL": -3, "SK": -1, "LU": 3},
                }
            },
            {
                "key": "k",
                "description": "udělit Maďarsku pokutu 200 000 000 EUR",
                "delay": -1,
                "impact": {
                    "satisfaction": {"CZ": -3, "HU": -10, "PL": -3, "SK": -1, "LU": 3},
                    "budget": 200_000_000,
                }
            },
            {
                "key": "o",
                "description": "odmítnout požadavek",
                "delay": -1,
                "impact": {
                    "satisfaction": {"HU": 3, "LU": -3, },
                    "budget": 200_000_000,
                }
            },
            {
                "key": "n",
                "description": "nerozhodnout teď",
                "delay": 2,
                "impact": {
                    "satisfaction": {"LU": -1},
                }
            },
        ]
    },
]



# coding: utf-8

ev_deep_state_nbm = [
    {
        "party": "NBM",
        "description": "Bill Gates oznámil otevření nových gigantických výrobních kapacit pro vakcíny, které by měly pomoci"
                       " při dalších pandemiích. Nyní požaduje aby byly zavedené povinné elektronické očkovací průkazy.",
        "flag": "pandemic",
        "options": [
            {
                "key": "p",
                "description": "přijmout zavedení povinných elektronických očkovacích průkazů",
                "delay": -1,
                "impact": {
                    "satisfaction": {
                        "NBM": 5, "WHO": 5, "GDA": 2, "SOR": 1, "BIT": 2, "BIP": 5, "BE": -3, "BG": -3, "CZ": -5, "DK": -2,
                        "EE": -3, "FI": -3, "FR": -5, "HR": -2, "IE": -2, "IT": -5, "CY": -2, "LT": -2, "ES": -2, "SE": -4,
                        "HU": -3, "MT": -1, "DE": -2, "NL": -2, "PL": -4, "PT": -2, "AT": -3, "RO": -3, "GR": -2, "SK": -5,
                        "SI": -3, "LV": -2, "LU": -2,
                    },
                }
            },
            {
                "key": "o",
                "description": "odmítnout zavedení povinných elektronických očkovacích průkazů",
                "delay": 12,
                "impact": {
                    "satisfaction": {
                        "NBM": -5, "WHO": -5, "GDA": -2, "SOR": -1, "BIT": -2, "BIP": -5, "BE": 3, "BG": 3, "CZ": 5, "DK": 2,
                        "EE": 3, "FI": 3, "FR": 5, "HR": 2, "IE": 2, "IT": 5, "CY": 2, "LT": 2, "ES": 2, "SE": 4, "HU": 3,
                        "MT": 1, "DE": 2, "NL": 2, "PL": 4, "PT": 2, "AT": 3, "RO": 3, "GR": 2, "SK": 5, "SI": 3, "LV": 2,
                        "LU": 2,
                    },
                }
            },
            {
                "key": "n",
                "description": "nerozhodnout teď",
                "delay": 2,
                "impact": {
                    "satisfaction": {"NBM": -1},
                }
            },
        ]
    },
]



header_1 = "yellow"
header_style = "cyan"
header_2 = "yellow"
option = "magenta"
cursor = "cyan"
proceed = "cyan"
numbers = "magenta"
high_power_events = "magenta"
positive_progress = "green"
negative_progress = "red"



import random
import eu2020.data.texts as texts
import eu2020.common.utils as utils
from eu2020.common.budget import Budget
from eu2020.common.parties import Parties
from eu2020.common.parties_events import PartiesEvents


class EventProcessor:

    events = set()
    flags = set()
    all_parties = Parties({})

    def __init__(self, flags: set):
        self.flags = flags

    def add_events(self, events: PartiesEvents) -> None:
        self.events.add(events)
        parties = events.get_parties().parties
        for p in parties:
            if p not in self.all_parties.parties:
                self.all_parties.parties[p] = parties[p]

    def process_events(self, budget: Budget) -> None:
        for evs in self.events:
            for _ in range(random.randint(1, 2)):
                ev = evs.get_event()
                if ev is not None:
                    country = evs.get_parties().parties[ev["party"]]
                    utils.print_text_in_box(country["name"])
                    self.make_decision(ev, self.all_parties, budget)

    def make_decision(self, ev: dict, members: Parties, budget: Budget) -> None:
        print(ev["description"])
        print()
        dopt = {}
        for opt in ev["options"]:
            dopt[opt["key"]] = opt["description"]
        g = utils.input_with_options(texts.options, dopt)
        options = list(filter(lambda o: o["key"] == g, ev["options"]))

        # Set delay
        ev["wait"] = options[0]["delay"]

        # Satisfaction
        if "satisfaction" in options[0]["impact"]:
            members.update_satisfaction(options[0]["impact"]["satisfaction"])

        # Budget
        if "budget" in options[0]["impact"]:
            if options[0]["impact"]["budget"] > 0:
                budget.add_extra_income(options[0]["impact"]["budget"])
            else:
                budget.add_extra_outcome(-1 * options[0]["impact"]["budget"])
        if "guarantee" in options[0]["impact"]:
            budget.add_guarantee(options[0]["impact"]["guarantee"])

        # Flag set
        if "flag_set" in options[0]:
            self.flags.add(options[0]["flag_set"])

    def next_period(self) -> None:
        for evs in self.events:
            evs.next_period()



# coding: utf-8

ev_member_country_fr = [
    {
        "party": "FR",
        "description": "Francie požaduje záruku za vydané státní dluhopisy ve výši 20 000 000 000 EUR.",
        "options": [
            {
                "key": "p",
                "description": "přijmout záruku",
                "delay": 12,
                "impact": {
                    "satisfaction": {"FR": 5},
                    "guarantee": 20_000_000_000
                }
            },
            {
                "key": "n",
                "description": "nepřijmout záruku",
                "delay": 3,
                "impact": {
                    "satisfaction": {"FR": -5},
                }
            },
        ]
    },
]



import eu2020.data.colors as colors
import eu2020.data.ev_admin as ead
import eu2020.data.ev_deep_state as eds
import eu2020.data.ev_members as ems
import eu2020.data.ev_others as eot
import eu2020.data.texts as texts
import eu2020.data.data as data
import eu2020.common.utils as utils
from eu2020.common.name import Name
from eu2020.common.period import Period
from eu2020.common.higher_power_events import HigherPowerEvents
from eu2020.common.parties_events import PartiesEvents
from eu2020.common.parties import Parties
from eu2020.common.budget import Budget
from eu2020.common.event_processor import EventProcessor
from eu2020.data.ev_higher_power import ev_higher_power
from eu2020 import console


def main() -> None:
    flags = set()

    eu_members = Parties(ems.member_countries)
    eu_admin = Parties(ead.eu_administration)
    deep_state = Parties(eds.deep_state)
    others = Parties(eot.deep_others)

    high_power_events = HigherPowerEvents(ev_higher_power, flags)
    eu_members_events = PartiesEvents(ems.ev_member_country, eu_members, flags)
    eu_admin_events = PartiesEvents(ead.ev_admin, eu_admin, flags)
    deep_events = PartiesEvents(eds.ev_deep_state, deep_state, flags)
    others_events = PartiesEvents(eot.ev_others, others, flags)

    event_processor = EventProcessor(flags)
    event_processor.add_events(eu_members_events)
    event_processor.add_events(eu_admin_events)
    event_processor.add_events(deep_events)
    event_processor.add_events(others_events)

    budget = Budget()
    budget.add_parties(eu_members)
    budget.add_parties(eu_admin)
    budget.add_parties(deep_state)

    data.period = Period(2020, 0)

    utils.clear()
    print_app_name()

    setup()
    print(texts.intro.format(data.name.get_name5p(), data.name.translate("stal"), len(ems.member_countries)))
    utils.proceed()

    while True:
        utils.print_text_in_box(texts.period.format(data.period.get_month(), data.period.get_year()))
        print_budget(budget)
        print_membership_satisfaction(eu_members)
        print_hp_events(high_power_events)
        print()
        utils.proceed()

        event_processor.process_events(budget)

        hpe = high_power_events.get_event()
        if hpe is not None:
            utils.print_text_in_box(texts.higher_power_event, "!")
            print(hpe + "\n")
            utils.proceed()

        utils.print_text_in_box(texts.membership_satisfaction_header)
        console.print(eu_members.get_detailed_satisfaction_report())
        utils.proceed()

        utils.print_text_in_box(texts.deep_state_satisfaction_header)
        console.print(deep_state.get_detailed_satisfaction_report())
        utils.proceed()

        data.period.next()
        event_processor.next_period()
        if data.period.month == 0:
            budget.update_balance()


def print_budget(budget: Budget) -> None:
    console.print(budget.get_budget_report())


def print_membership_satisfaction(members: Parties) -> None:
    console.print(texts.membership_satisfaction.format(colors.numbers, members.get_satisfaction_pct(), colors.numbers))


def print_hp_events(hp_events: HigherPowerEvents) -> None:
    ev = hp_events.get_current_events()
    if ev != "":
        console.print()
        console.print(texts.higher_power_events.format(colors.high_power_events, ev, colors.high_power_events))


def setup() -> None:
    n = console.input(f"{texts.what_is_your_name}\n{texts.cursor}")
    print()
    g = utils.input_with_options(texts.what_is_your_gender, data.gender)
    data.name = Name(n, g)


def print_app_name() -> None:
    utils.print_text_in_box(texts.app_name)



import random
from typing import Optional

from eu2020.common.parties import Parties


class PartiesEvents:

    events = []
    flags = set()
    parties = None

    def __init__(self, events: list, parties: Parties, flags: set):
        self.events = events
        self.flags = flags
        for ev in self.events:
            ev["wait"] = 0
        self.parties = parties

    def event_filter(self, ev: dict) -> bool:
        if "flag" in ev:
            if ev["flag"] not in self.flags:
                return False

        return ev["wait"] == 0

    def get_event(self) -> Optional[dict]:
        filtered = list(filter(self.event_filter, self.events))
        if filtered:
            return random.choice(filtered)
        return None

    def get_parties(self) -> Parties:
        return self.parties

    def next_period(self) -> None:
        for ev in self.events:
            if ev["wait"] > 0:
                ev["wait"] -= 1

        self.parties.next_period()



# coding: utf-8

from eu2020.data.ev_admin_eb import ev_admin_eb
from eu2020.data.ev_admin_ek import ev_admin_ek
from eu2020.data.ev_admin_es import ev_admin_es

ev_admin = []
ev_admin += ev_admin_eb
ev_admin += ev_admin_ek
ev_admin += ev_admin_es

eu_administration = {
    "EK": {
        "name": "Evropská komise",
        "satisfaction_pct": 50,
        "budget_contribution": 0,
        "budget_consumption": 3_000_000_000,
    },
    "ER": {
        "name": "Rada Evropy",
        "satisfaction_pct": 50,
        "budget_contribution": 0,
        "budget_consumption": 0,
    },
    "EP": {
        "name": "Evropský parlament",
        "satisfaction_pct": 50,
        "budget_contribution": 0,
        "budget_consumption": 10_000_000_000,
    },
    "ES": {
        "name": "Evropský soudní dvůr",
        "satisfaction_pct": 50,
        "budget_contribution": 0,
        "budget_consumption": 1_250_000_000,
    },
    "EB": {
        "name": "Evropská centrální banka",
        "satisfaction_pct": 50,
        "budget_contribution": 0,
        "budget_consumption": 1_250_000_000,
    },
    "AD": {
        "name": "Administrativa",
        "satisfaction_pct": 50,
        "budget_contribution": 0,
        "budget_consumption": 2_500_000_000,
    },
    "PR": {
        "name": "EU Propagace",
        "satisfaction_pct": 50,
        "budget_contribution": 0,
        "budget_consumption": 5_000_000_000,
    },
    "ED": {
        "name": "Evropská obranná Agentura",
        "satisfaction_pct": 50,
        "budget_contribution": 0,
        "budget_consumption": 5_000_000_000,
    },
}



# coding: utf-8

ev_deep_state_sor = [
    {
        "party": "SOR",
        "description": "George Soros požaduje rychlejší přísun migrantů z Afriky. Nabízí příspěvek 1 000 000 000 EUR "
                       "jako podporu pro lidskoprávní organizace.",
        "options": [
            {
                "key": "p",
                "description": "přijmout",
                "delay": 12,
                "impact": {
                    "satisfaction": {"SOR": 8, "CZ": -3, "HU": -3, "PL": -3, "SK": -3, "AT": -3, "IT": -3, "FR": -2},
                    "budget": 1_000_000_000,
                }
            },
            {
                "key": "o",
                "description": "odmítnout",
                "delay": 6,
                "impact": {
                    "satisfaction": {"SOR": -10, "NEZ": -5, "WHO": -2},
                }
            },
            {
                "key": "n",
                "description": "nerozhodnout teď",
                "delay": 2,
                "impact": {
                    "satisfaction": {"SOR": -3, },
                }
            },
        ]
    },
]
